==> haskell-crypto-api-0.13.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.3
id: crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
key: crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
abi: 6900b771227d4e4da26f3f5981befd1d
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util
hidden-modules: Crypto.CPoly
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-0.13.3
hs-libraries: HScrypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=bbba9b47b66235cbe49005ce0f2ca1a5
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-0.13.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.3
id: crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
key: crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
abi: ce10e49cbca1b74596de9d427ce328a8
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util
hidden-modules: Crypto.CPoly
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-0.13.3
hs-libraries: HScrypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=bbba9b47b66235cbe49005ce0f2ca1a5
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
